#
# spec file for package perl-Log-Dispatch-FileRotate
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Log-Dispatch-FileRotate
Version:        1.35
Release:        lp150.1.1
%define cpan_name Log-Dispatch-FileRotate
Summary:        Log to Files that Archive/Rotate Themselves
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Log-Dispatch-FileRotate/
Source0:        https://cpan.metacpan.org/authors/id/M/MS/MSCHOUT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Date::Manip)
BuildRequires:  perl(Log::Dispatch)
BuildRequires:  perl(Log::Dispatch::File)
BuildRequires:  perl(Log::Dispatch::Output)
BuildRequires:  perl(Log::Dispatch::Screen)
BuildRequires:  perl(Path::Tiny) >= 0.018
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn)
BuildRequires:  perl(version)
Requires:       perl(Date::Manip)
Requires:       perl(Log::Dispatch::File)
Requires:       perl(Log::Dispatch::Output)
Requires:       perl(version)
%{perl_requires}

%description
This module extends the base class Log::Dispatch::Output to provides a
simple object for logging to files under the Log::Dispatch::* system, and
automatically rotating them according to different constraints. This is
basically a Log::Dispatch::File wrapper with additions.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README
%license LICENSE

%changelog
* Thu Mar  8 2018 coolo@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.35 Wed 43 07 2018
  - Fix lockfile race condition test in Strawberry Perl (Thanks Zak B. Elep)
  - Skip file open failure test on Cygwin - chmod bahaviour varies on Cygwin
    (Zak B. Elep)
  - Minor test cleanups (Zak B. Elep)
  - Fix "Use of "localtime" without parentheses" warning on older Perls
  - Migrate issues/bug tracking from rt.cpan.org to Github issues.
* Thu Sep 14 2017 coolo@suse.com
- updated to 1.34
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.34 Wed 55 13 2017
  - We now use a a global Mutex object for each open file that gracefully
    handles locking between threads and across forks.  This fixes the
    following deadlock scenarios:
  - a $SIG{__WARN__} handler is installed that logs to
    Log::Dispatch::FileRotate and log_message issues a warning.
  - multiple dispatchers are in logit() at the same time.
  - Abstract locking functions into Log::Dispatch::FileRotoate::Flock module.
  - Remove flock()'ing of the logfile filehandle.  Rely on the lock that
    we hold on the "lockfile" instead to synchronize writes. [Github #12]
    holding a lock on the lockfile when writing the log message.
  - Various pod cleanups and enhancements (Thanks Emanuele Tomasi)
  - Avoid multiple stat() calls on the same filehandle (Thanks Emanuele Tomasi)
  - Add user_constraint option to use a custom function to determine when
    rotation happens (Thanks Emanuele Tomasi).
  - Move rotation code into its own function (Thanks Emanuele Tomasi)
* Tue Aug 15 2017 coolo@suse.com
- updated to 1.30
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.30 Thu Aug 03 2017
  - Docs: fix synopsis usage to "name" (incorrect) instead of filename
    (correct) (Thanks Emanuele Tomasi)
  - improve debug() routine so that all debug messages have the same layout
    (Thanks Emanuele Tomasi)
  - fix race condition in lockfile-race-condition.t [sic] (Thanks Emanuele
    Tomasi)
* Thu Aug  3 2017 coolo@suse.com
- updated to 1.29
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.29 Fri Jul 28 2017
  - Fix deadlock on Windows due to the fact that stat() on a filehandle vs a
    path doesn't return the same device field on Windows.
* Fri Jul 28 2017 coolo@suse.com
- updated to 1.28
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.28 Thu Jul 27 2017
  * ** Multiple fixes to locking code:
  - flock() can be interrupted by a syscall. work around by using a
    safe_flock() wrapper that retries if errno is EAGAIN (and also
    EWOULDBLOCK).
  - handle several possible race conditions between open() and flock().
  - DESTROY() was unlinking the lockfile (.logfile.LCK).  This was the cause
    of a race condition where multiple processes could enter the critical
    seciton at the same time.  Avoided by leaving .LCK files in place.
    Probably fixes #77075 (Thanks Emanuele Tomasi).
  - add author test for DESTROY lockfile race condition.
* Fri Jul  7 2017 coolo@suse.com
- updated to 1.27
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.27 Thu Jul 06 2017
  - add "check_both" configuration option which allows the use of both time and
    size based rotation at the same time.  If either conditions require a
    rotation, a rotation will happen.  Default is false (previous behaviour).
    Thanks Emanuele Tomasi.  PR #6.
  - make signature test an "author" test and make Test::Signature optional
* Wed May 10 2017 coolo@suse.com
- updated to 1.26
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.26 Tue May 09 2017
  - add SEE ALSO reference to Log::Dispath::File::Stamped (Thanks Karen
    Etheridge)
* Tue Apr 11 2017 coolo@suse.com
- updated to 1.25
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.25 Mon Apr 10 2017
  - Fix test failures if the test suite is running as root user.
* Wed Feb 15 2017 coolo@suse.com
- updated to 1.24
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.24 Tue Feb 14 2017
  - fix test failure on file-open-failure.t related to current locale
    setting.
  - improve fix to Date::Manip TZ deprecation warnings.
* Mon Feb 13 2017 coolo@suse.com
- updated to 1.23
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.23 Thu Feb 09 2017
  - Issue a warning if the lockfile cannot be opened (Thanks KGOESS)
    [#63544]
  - Fix POD typo (Thanks Anirvan Chatterjee)
* Fri Oct  7 2016 coolo@suse.com
- updated to 1.22
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
* Sun Oct  2 2016 coolo@suse.com
- updated to 1.20
  see /usr/share/doc/packages/perl-Log-Dispatch-FileRotate/Changes
  1.20 Sat Oct 01 2016
  - Fix Date::Manip warnings about deprecated TZ config variable. If
  Date::Manip 6.x or later is installed we now use SetDate instead.
* Fri Nov 18 2011 coolo@suse.com
- use original tar.gz
* Tue Aug 30 2011 andrea.turrini@gmail.com
- standardized "Authors:" format in description of
  perl-Log-Dispatch-FileRotate.spec
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sun Apr  4 2010 chris@computersalat.de
- fix deps
  o Req perl-Log-Log4perl
* Sat Dec 12 2009 chris@computersalat.de
- initial pkg 1.19
